@@ -1,5 +1,7 @@
-require "benchmark/memory/held_results/serializer"
-require "benchmark/memory/measurement/metric"
+# frozen_string_literal: true
+
+require 'benchmark/memory/held_results/serializer'
+require 'benchmark/memory/measurement/metric'
 
 module Benchmark
   module Memory
@@ -14,9 +16,9 @@ module Benchmark
         #
         def load(hash)
           @object = Measurement::Metric.new(
-            hash["type"],
-            hash["allocated"],
-            hash["retained"]
+            hash['type'],
+            hash['allocated'],
+            hash['retained']
           )
           self
         end
@@ -26,9 +28,9 @@ module Benchmark
         # @return [Hash] The metric as a Hash.
         def to_h
           {
-            :allocated => object.allocated,
-            :retained  => object.retained,
-            :type      => object.type,
+            allocated: object.allocated,
+            retained: object.retained,
+            type: object.type
           }
         end
       end
