@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Benchmark
   module Memory
     class Job
@@ -6,20 +8,17 @@ module Benchmark
         # Swallow entry output.
         #
         # @return [void]
-        def put_entry(entry)
-        end
+        def put_entry(entry); end
 
         # Swallow comparison output.
         #
         # @return [void]
-        def put_comparison(comparison)
-        end
+        def put_comparison(comparison); end
 
         # Swallow header output.
         #
         # @return [void]
-        def put_header
-        end
+        def put_header; end
       end
     end
   end
