@@ -1,5 +1,7 @@
-require "memory_profiler"
-require "benchmark/memory/measurement"
+# frozen_string_literal: true
+
+require 'memory_profiler'
+require 'benchmark/memory/measurement'
 
 module Benchmark
   module Memory
@@ -14,7 +16,7 @@ module Benchmark
         # @raise [ArgumentError] if the action does not respond to `#call`.
         def initialize(label, action)
           unless action.respond_to?(:call)
-            fail(
+            raise(
               ArgumentError,
               "Invalid action (#{@action.inspect} does not respond to call)"
             )
