@@ -1,12 +1,12 @@
-require "benchmark/memory/helpers"
+# frozen_string_literal: true
+
+require 'benchmark/memory/helpers'
 
 module Benchmark
   module Memory
     class Measurement
       # Describe the ratio of allocated vs. retained memory in a measurement.
       class Metric
-        include Comparable
-
         # Instantiate a Metric of allocated vs. retained memory.
         #
         # @param type [Symbol] The type of memory allocated in the metric.
@@ -26,15 +26,6 @@ module Benchmark
 
         # @return [Symbol] The type of memory allocated in the metric.
         attr_reader :type
-
-        # Sort by the total allocated.
-        #
-        # @param other [Metric] The other metric.
-        #
-        # @return [Integer]
-        def <=>(other)
-          allocated <=> other.allocated
-        end
       end
     end
   end
