@@ -1,5 +1,7 @@
-require "benchmark/memory/report/comparison"
-require "benchmark/memory/report/entry"
+# frozen_string_literal: true
+
+require 'benchmark/memory/report/comparison'
+require 'benchmark/memory/report/entry'
 
 module Benchmark
   module Memory
@@ -10,8 +12,12 @@ module Benchmark
       # @return [Report]
       def initialize
         @entries = []
+        @comparator = Comparator.new
       end
 
+      # @return [Comparator] The {Comparator} to use when creating the {Comparison}.
+      attr_accessor :comparator
+
       # @return [Array<Entry>] The entries in the report.
       attr_reader :entries
 
@@ -38,7 +44,7 @@ module Benchmark
       #
       # @return [Comparison]
       def comparison
-        @comparison ||= Comparison.new(entries)
+        @comparison ||= Comparison.new(entries, comparator)
       end
     end
   end
