@@ -1,12 +1,15 @@
-require "spec_helper"
+# frozen_string_literal: true
+
+require 'spec_helper'
 
 RSpec.describe Benchmark::Memory::Report::Comparison do
-  describe "#entries" do
-    it "is sorted from smallest allocation to largest" do
+  describe '#entries' do
+    it 'is sorted from smallest allocation to largest' do
       high_entry = create_high_entry
       low_entry = create_low_entry
+      comparator = Benchmark::Memory::Report::Comparator.from_spec({})
 
-      comparison = described_class.new([high_entry, low_entry])
+      comparison = described_class.new([high_entry, low_entry], comparator)
 
       expect(comparison.entries).to eq([low_entry, high_entry])
     end
@@ -14,7 +17,7 @@ RSpec.describe Benchmark::Memory::Report::Comparison do
 
   def create_high_entry
     Benchmark::Memory::Report::Entry.new(
-      "high",
+      'high',
       create_measurement(10_000, 5_000)
     )
   end
@@ -22,7 +25,7 @@ RSpec.describe Benchmark::Memory::Report::Comparison do
 
   def create_low_entry
     Benchmark::Memory::Report::Entry.new(
-      "low",
+      'low',
       create_measurement(2_500, 1_250)
     )
   end
@@ -45,9 +48,9 @@ RSpec.describe Benchmark::Memory::Report::Comparison do
     )
 
     Benchmark::Memory::Measurement.new(
-      :strings => strings,
-      :objects => objects,
-      :memory => memsize
+      strings: strings,
+      objects: objects,
+      memory: memsize
     )
   end
 end
